import 'dart:convert';

import 'package:feedify/src/model/ad/model_ad_request.dart';
import 'package:feedify/src/model/notification/model_notification.dart';
import 'package:feedify/src/model/register/register_request.dart';
import 'package:http/http.dart' as http;

import '../../logs.dart';

class ApiProvider {
  static const _register_url = 'https://feedify.net/push/register';
  static const _fetch_ad_url = 'https://deliver.feedify.net/fetch-ad';
  static const _delivery_count_url =
      'https://deliver.feedify.net/deliveryCount';
  static const _payload_data_api = 'https://deliver.feedify.net/deliver';
  static const _clicks_api = 'https://deliver.feedify.net/click';

  void register(RegisterRequest registerRequest) async {
    Logs.d('registration init ');
    var registerMap = registerRequest.toMap();
    Logs.d('registration data :: $registerMap');
    http.Response response = await http.post(
      Uri.parse(_register_url),
      body: registerMap,
    );
    if (response.statusCode == 200) {
      Logs.d('registration success :: ${response.statusCode}');
    } else {
      Logs.d('registration failed :: ${response.statusCode}');
    }
  }

  Future<ModelNotification?> fetchAd(ModelAdRequest modelAdRequest) async {
    Logs.d('fetchAd init ');
    var adMap = modelAdRequest.toMap();
    http.Response response = await http.post(
      Uri.parse(_fetch_ad_url),
      body: jsonEncode(adMap),
      headers: {
        'Content-type': 'application/json',
        'Accept': 'application/json'
      },
    );
    if (response.statusCode == 200) {
      Logs.d('fetchAd success :: ${response.statusCode}');
      return ModelNotification.fromJson(jsonDecode(response.body));
    } else {
      Logs.d('fetchAd failed :: ${response.statusCode}');
      return null;
    }
  }

  void countDelivery(String id, String type) async {
    Logs.d('countDelivery id:: $id, type:: $type');
    http.Response response = await http.get(
        Uri.parse(
            _delivery_count_url + '?' + _getDeliveryCountUrlParams(id, type)),
        headers: {
          'Content-type': 'application/json',
          'Accept': 'application/json'
        });
    Logs.d(
        'countDelivery:: status code ${response.statusCode}, response :: ${response.body}');
  }

  String _getDeliveryCountUrlParams(String id, String type) {
    return "type=" + Uri.encodeFull(type) + "&id=" + Uri.encodeFull(id);
  }

  callClickApi(String id, String type) async {
    Logs.d('callClickApi id:: $id, type:: $type');
    http.Response response = await http.get(
        Uri.parse(_clicks_api + '?' + _getDeliveryCountUrlParams(id, type)),
        headers: {
          'Content-type': 'application/json',
          'Accept': 'application/json'
        });
    Logs.d(
        'callClickApi:: status code ${response.statusCode}, response :: ${response.body}');
  }
}
